dual_pairs: Computing with dual pairs of algebras
=================================================

License
-------

GPL 3


Upstream Contact
----------------

- https://github.com/passagemath/passagemath-pkg-dual-pairs
- https://gitlab.com/pbruin/dual-pairs
